@@ -23,20 +23,25 @@ impl<'a> AstGroupItem<'a> {
     /// [`AstGroup`] or [`AstStyle`]
     #[inline]
     pub fn parse(input: &'a str) -> IResult<&'a str, Self> {
-        alt((Self::parse_nested, Self::parse_style))(input)
-    }
-    #[inline]
-    fn parse_style(input: &'a str) -> IResult<&'a str, Self> {
-        AstStyle::parse(input).map(|(rest, ok)| (rest, Self::Styled(ok)))
+        let (rest, (head, group)) = tuple((AstStyle::parse, opt(AstGroup::parse_many)))(input)?;
+        let out = match group {
+            None => Self::Styled(head),
+            Some(children) => Self::Grouped(AstGroup { head, children }),
+        };
+        Ok((rest, out))
     }
     // #[inline]
+    // fn parse_style(input: &'a str) -> IResult<&'a str, Self> {
+    //     AstStyle::parse(input).map(|(rest, ok)| (rest, Self::Styled(ok)))
+    // }
+    // #[inline]
+    // fn parse_nested(input: &'a str) -> IResult<&'a str, Self> {
+    //     AstGroup::parse(input).map(|(rest, ok)| (rest, Self::Grouped(ok)))
+    // }
+    // #[inline]
     // fn parse_self(input: &'a str) -> IResult<&'a str, Self> {
     //     AstReference::parse(input).map(|(rest, ok)| (rest, Self::SelfReference(ok)))
     // }
-    #[inline]
-    fn parse_nested(input: &'a str) -> IResult<&'a str, Self> {
-        AstGroup::parse(input).map(|(rest, ok)| (rest, Self::Grouped(ok)))
-    }
 }
 
 impl<'a> AstStyle<'a> {
